/*******************************************************************************

	Export regression results to csv for later treatment in Matlab

********************************************************************************/

/****************************************************************************
	Date: July, 2013
	
	Program: csvexport
	
	This file:
	- Starts from the output files of microestimation
	- Exports in csv for later import in Matlab
	- Calls the following programs (saved in $dopath): 
		1) matlab_prep.do
	
	Inputs: 
	- working paths
	- name of the log file
	- macro variables:
		"samplename" used to name output files
		"sect" the name of the variable identifying sectors
		"variable" the variable of interest
		"controls" the set of firm-level variable used as control in robustness checks.
	
	Output:
		- Datasets with estimated components of individual growth rates
		1) $outputpath/growth_regs_capays_$samplename
		2) $outputpath/FR_growth_regs_capays_$samplename
		3) $outputpath/X_growth_regs_capays_$samplename
		4) $outputpath/growth_`control'_regs_capays_$samplename for each control in $controls
		5) $outputpath/growth_localFE_regs_capays_$samplename
		6) $outputpath/growth_regs_vapays_$samplename

****************************************************************************/

*** Define working path 
global dopath W:\Granularity\DoFiles\ECMA
global datapath E:\temp\MEJEAN\dGLM
global outputpath E:\temp\MEJEAN\dGLM\Output

*** Define the macro variables
global samplename="mfg"
global sect = "naf60"
global variable capays
global controls = "pct_size classage RD pat openness pct_totdebt"

log using $outputpath\cvsexport_$samplename, text replace

*** Load in do files run later on
cd "$dopath"
quietly do matlab_prep

*** Benchmark, Whole sample (Tables 2,3,5, Panel I) 
use $outputpath/growth_regs_capays_$samplename, clear
matlab_prep $outputpath/growth_regs_capays_$samplename 0 gr_$variable
	
*** Benchmark, Domestic only (Tables 2,3,5, Panel II)
use $outputpath/growth_regs_capays_$samplename, clear
keep if pays=="FR"
matlab_prep $outputpath/FR_growth_regs_capays_$samplename 0 gr_$variable

*** Benchmark, Export only (Tables 2,3,5, Panel III)
use $outputpath/growth_regs_capays_$samplename, clear
keep if pays~="FR"
matlab_prep $outputpath/X_growth_regs_capays_$samplename 0 gr_$variable

*** Estimation on level growth rates, with sectoral fixed effects interacted with firm-specific variables (Table A2)
foreach control in $controls{
	use $outputpath/growth_`control'_interacted_regs_capays_$samplename, clear
	matlab_prep $outputpath/growth_`control'_interacted_regs_capays_$samplename 1 gr_$variable
}

*** Estimation on level growth rates using additional local effects to control for shocks on the local labor market (Panel III of Table A3)
use $outputpath/growth_localFE_regs_capays_$samplename, clear
matlab_prep $outputpath/growth_localFE_regs_capays_$samplename 0 gr_$variable 

*** Estimation on level growth rates using value added instead of sales as LHS variable (Tables 2,3,5, Panel IV) 
use $outputpath/growth_regs_vapays_$samplename, clear
matlab_prep $outputpath/growth_regs_vapays_$samplename 0 gr_vapays

log close
