clear
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Date: August 22, 2013
%
% Program: Thsi file computes the decomposition of the firm-specific
% component into a DIRECT and a LINK term and draw a picture over time.
% Sample: Whole Economy
%
% References to the following functions:
%   var_growth.m Aggregate variance and components, based on constant
%   weights
%   var_only_growth.m aggregate variance and components, neglecting
%   within-component covariances
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

load Output/reg_output_all_ca;
gr_sales = gr_variable;
gr_macsec = gr_macro+gr_sec;

% Calculate variances/covariances

[VAR_idio,var_idio,sd_idio] = var_growth(id_fp,year,gr_idio,w_fp);

% Calculates variances only

[var_only_idio sd_only_idio] = var_only_growth(id_fp,year,gr_idio,w_fp);

% direct versus link

var_direct = var_only_idio;
var_link = var_idio-var_only_idio;
sd_direct = sqrt(var_direct);
sd_link = sqrt(var_link);


% Save data to output file

save Output/directlink_compare_ALL VAR_* var_* sd_idio*;

% Figure

t = linspace(1991,2007,17);
plot(t,sd_idio,'k-',t,sd_only_idio,'k-.',t,sd_link,'k--','LineWidth',1.5);
legend('Firm-Specific','DIRECT^{1/2}','LINK^{1/2}','Location','Best');
ylabel('Standard Deviation','FontSize',16);
set(gca,'FontSize',12);
grid 'on';
print -depsc2 Figures/directlink_ALL;
