/*
	Date: December 2012
	
	Program: this program runs the regressions to compute the idiosyncractic, sector, and macro 
				components of domestic or bilateral export sales growth. Following K&T (2008), we will 
				run a regression or each year individually, as well as each destination market. 
				In comparison with the benchmark in growth_reg.do, this file adds local market effects
			
			`1': growth variable
         	`2': sector variable
          	`3': year to keep
            `4': sector number to constrain
*/

capture program drop growth_reg_localef
program define growth_reg_localef
   keep if year == `3'

   /***********************************************************************************
    Regression: we can use fe and then back out sector effects using built in command
                and constant captures the time effect, so we'll save that too.
                Will run for each year, starting with first year with growth rates to
                initialize variables to collect results
   ************************************************************************************/

   * Create dummies for local effects
   egen zenum=group(id_z)
   quietly tab zenum, ge(ze_)
   quietly sum zenum
   local nbze = r(max)
   
   * Create dummies and set up constrained sector, needed given that NAF  don't increase uniformly
   * Refsect has to be the last one => replace

   egen naf_num = group(`2')
   quietly sum naf_num if `2'==`4'
   local sc = r(min)
   quietly sum naf_num
   local nbsec = r(max)
   quietly tab naf_num, ge(sec)

   constraint 1 sec`sc' = 0
   constraint 2 ze_1 = 0

   * Regression

   quietly cnsreg `1' sec* ze_*, c(1-2)

   * Idiosyncratic shock

   predict gr_idio, res
   
   * R-squared
   
   predict `1'_hat
   corr `1' `1'_hat if e(sample) 
   ge Rsquared=r(rho)^2


   * Sector-level shocks

   mat b = e(b)

   mat b_sec = b[1,1..(`nbsec')]	
   
   ge gr_sec = 0
   local cb = `nbsec'
   quietly foreach X of numlist 1/`cb'{
		replace gr_sec = b_sec[1,`X'] if sec`X' == 1
	}
	corr `1' gr_sec if e(sample) 
	ge Rspart_sec=r(rho)^2

	* Adjust R squared
	quietly sum `1' if e(sample)
	local count=r(N)
	g countreg=colsof(b)
	quietly sum countreg
	local countreg=r(mean)
	ge Rbarsquared=1-(1-Rsquared)*(`count'-1)/(`count'-`countreg'-1)
	
	* Local shocks

   mat b_ze = b[1,`nbsec'+1..`nbze']	
   
   ge gr_ze = 0
   local cb = `nbze'
   quietly foreach X of numlist 1/`cb'{
		replace gr_ze = b_ze[1,`X'] if ze_`X' == 1
	}
	corr `1' gr_ze if e(sample) 
	ge Rspart_ze=r(rho)^2
	
   * Macro shocks

    ge gr_macro = b[1,colsof(b)]
   	corr `1' gr_macro if e(sample) 
	ge Rspart_macro=r(rho)^2
	* this is necessarily zero since gr_macro is a constant...
	
	keep siren id* `2' year `1' pays gr_idio gr_sec gr_macro Rsquared Rbarsquared Rspart_sec Rspart_macro `1'_hat w_fn gr_ze Rspart_ze
	compress
end
