/*
	Date: March 28, 2011
	
	Program: this program runs the regressions to compute the idiosyncractic, sector, and macro 
				components of domestic or bilateral export sales growth. Following K&T (2008), we will 
				run a regression for each year individually, as well as each destination market.

            Given that we have collinearity if we include all sector effects and destination, and we 
            want to be transparent throughout, we will follow the approach of Stockman (1988) and 
            place some constraints on the coefficients. In this case, we need to constrain one 
            sector dummy to be zero. This cannot be done with the xtreg command, so we will create
            fixed effects using dummies, and constrain a given sector to be 0 throughout. 
			
			`1': demeaned growth variable
         	`2': sector variable
          	`3': year to keep
            `4': sector number to constrain
*/

capture program drop growth_regs
program define growth_regs
   keep if year == `3'

   /***********************************************************************************
    Regression: we can use fe and then back out sector effects using built in command
                and constant captures the time effect, so we'll save that too.
                Will run for each year, starting with first year with growth rates to
                initialize variables to collect results
   ************************************************************************************/

   * Create dummies and set up constrained sector, needed given that NAF  don't increase uniformly
   * Refsect has to be the last one => replace

   egen naf_num = group(`2')
   quietly sum naf_num if `2'==`4'
   local sc = r(min)
   quietly tab naf_num, ge(sec)

   constraint 1 sec`sc' = 0

   * Regression

   quietly cnsreg `1' sec*, c(1)

   * Idiosyncratic shock

   predict gr_idio, res
   
   * R-squared
   
   predict `1'_hat
   corr `1' `1'_hat if e(sample) 
   ge Rsquared=r(rho)^2


   * Sector-level shocks

   mat b = e(b)

   mat b_sec = b[1,1..(colsof(b)-1)]	
   
   ge gr_sec = 0
   local cb = colsof(b)-1
   quietly foreach X of numlist 1/`cb'{
		replace gr_sec = b_sec[1,`X'] if sec`X' == 1
	}
	corr `1' gr_sec if e(sample) 
	ge Rspart_sec=r(rho)^2

	* Adjust R squared
	quietly sum `1' if e(sample)
	local count=r(N)
	g countreg=colsof(b)
	quietly sum countreg
	local countreg=r(mean)
	ge Rbarsquared=1-(1-Rsquared)*(`count'-1)/(`count'-`countreg'-1)
	
   * Macro shocks

    ge gr_macro = b[1,colsof(b)]
   	corr `1' gr_macro if e(sample) 
	ge Rspart_macro=r(rho)^2
	* this is necessarily zero since gr_macro is a constant...
	
	keep siren id* `2' year `1' pays gr_idio gr_sec gr_macro Rsquared Rbarsquared Rspart_sec Rspart_macro `1'_hat w_fn
	compress
end
