/*
   Date: May 29, 2011
	
   Program: this program decomposes market-specific individual growth rates into a firm, a sector and an aggregate components. 
                                    the firm-specific component into a common and a market-specific shocks
						 controls for firm-specific characteristics and their interaction with FE
   
   
            `1': input file
			`2': Sector variable
			`3': Reference sector
			`4': Growth variable
			`5': Control variable
			`6': Output file
*/

capture program drop interacted_growth_regs
program define interacted_growth_regs

*** First stage: Idio/sector/macro
set more off
cd $datapath
use `1', clear
sum id_p
local min_id_p = r(min)
local max_id_p = r(max)

foreach P of numlist `min_id_p'/`max_id_p'{
	keep if id_p==`P'
	sum year if id_p==`P'

	local min_year = r(min)
	local max_year = r(max)

	save temp_`P',replace
	foreach Y of numlist `min_year'/`max_year'{
		keep if year == `Y'
		sort `2'
		by `2': egen count=count(`4') if `4'!=. & `5'!=.
		drop if count==1
		egen naf_num = group(`2')
		quietly sum naf_num if `2'==`3'
		local sc = r(min)
		quietly tab naf_num, ge(sec)
		quietly sum naf_num
		local nafmin = r(min)
		local nafmax = r(max)
		local g = `nafmax'
		foreach N of numlist `nafmin'/`nafmax'{	
			ge sizesec`N'=`5'*sec`N'
			corr sizesec`N' sec`N'
			local rho = r(rho)
			quietly sum naf_num if `N'==naf_num
			local obs = r(N)
			if `rho'>=.9999 | `obs'<=4{
				drop sizesec`N'	
				local g = `g'-1
			}
		}
		quietly tab `5' if naf_num==`sc'
		local psc=r(r)

		quietly count
		local count = r(N)

		if `count'>25 & `g'>1 & `psc'>1{
			constraint 1 sec`sc' = 0
			constraint 2 sizesec`sc' = 0
   
			* Regression

			quietly cnsreg `4' `5' sec* sizesec* , c(1-2)

			* Idiosyncratic shock

			predict gr_idio, res
   
			* R-squared
   
			predict `4'_hat
			corr `4' `4'_hat if e(sample) 
			ge Rsquared=r(rho)^2

	
			* Estimated coefficients

			mat b = e(b)
			mat b_size=b[1,1]
			mat b_sec = b[1,2..`nafmax'+1]
			mat b_sizesec = b[1,`nafmax'+2..(colsof(b)-1)]
			mat b_macro = b[1,colsof(b)]
	
	
			* Adjust R squared
			quietly sum `4' if e(sample)
			local count=r(N)
			g countreg=colsof(b)
			quietly sum countreg
			local countreg=r(mean)
			ge Rbarsquared=1-(1-Rsquared)*(`count'-1)/(`count'-`countreg'-1)
	
	
			* Sector-level shocks

			ge gr_sec = 0
			local cb = colsof(b_sec)
			quietly foreach X of numlist 1/`cb'{
				replace gr_sec = b_sec[1,`X'] if sec`X' == 1
			}
			corr `4' gr_sec if e(sample) 
			ge Rspart_sec=r(rho)^2

			* sector-level shocks interacted with size
	
			ge gr_sizesec = 0
			local cb = colsof(b_sizesec)
			capture quietly foreach X of numlist 1/`cb'{
				replace gr_sizesec = b_sizesec[1,`X']*`5' if sec`X'== 1
			}
			corr `4' gr_sizesec if e(sample)
			ge Rspart_sizesec=r(rho)^2
	
			* size effect
	
			ge gr_size= b_size[1,1] * `5'
			corr `4' gr_size if e(sample)
			ge Rspart_size=r(rho)^2
	
			* Macro shocks

			ge gr_macro = b_macro[1,1]
			corr `4' gr_macro if e(sample) 
			ge Rspart_macro=r(rho)^2
			* this is necessarily zero since gr_macro is a constant...
		}
		else{
			ge gr_idio=0
			ge `4'_hat=0
			ge Rsquared=0
			ge Rbarsquared=0
			ge gr_sec=0
			ge Rspart_sec=0
			ge gr_sizesec=0
			ge Rspart_sizesec=0
			ge gr_size=0
			ge Rspart_size=0
			ge gr_macro=0
			ge Rspart_macro=0
		}
		keep siren id* `2' year `4' `5' pays gr_idio gr_sec gr_size gr_sizesec gr_macro Rsquared Rbarsquared Rspart_sec Rspart_macro Rspart_size Rspart_sizesec `4'_hat w_fn
		compress
		save temp`P'`Y', replace
		use temp_`P', clear
	}
	use temp`P'`min_year', clear
	local min_year1 = `min_year'+1
	foreach X of numlist `min_year1'/`max_year'{
		append using temp`P'`X'
		erase temp`P'`X'.dta
	}
	sort pays year
	save growth_`P'_regs, replace
	erase temp`P'`min_year'.dta
    erase temp_`P'.dta
	use `1', clear
}

local min_id_p1 = `min_id_p'+1
use growth_`min_id_p'_regs, clear
foreach P of numlist `min_id_p1'/`max_id_p'{
	append using growth_`P'_regs
	erase growth_`P'_regs.dta
}

save `6', replace
erase growth_`min_id_p'_regs.dta

*** Second stage: Firm-common/Firm-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated firm-level residuals
	that were estimated in the first-step
	regressions above.
	
	Note: regress for firms that have at 
	2mkts so we can identify correctly
*******************************************/

use `6', clear

capture egen id_p = group(pays)
egen q = count(id_p), by(siren year)

egen gr_idio_com = mean(gr_idio) if q>1, by(siren year)
ge gr_idio_dest = gr_idio - gr_idio_com if q>1
keep siren pays year gr_idio_com gr_idio_dest w_fn
sort siren pays year

save temp_idio, replace

use `6', clear
sort siren pays year
merge siren pays year using temp_idio
tab _m
drop _m

sort siren pays year
save `6', replace


end
