clear
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Date: September 12, 2013
%
% Program: This file plots figures for aggregate variance and components 
% +/- one standard error, or 5th/95th percentiles. Save as EPS in Figures 
% folder. Sample: Manufacturing sector
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% Analytical and Bootstrap together

load Output/st_errors_MFG
load Output/st_errors_BS_MFG

t = linspace(1991,2007,17);

figure(1)
plot(t,sd_sales-1.96*sd_sales_se,'k--',t,prctile(sd_sales_BS,2.5,2),'k:', ...
    t,sd_sales,'ko-',t,sd_sales+1.96*sd_sales_se,'k--',t,prctile(sd_sales_BS,97.5,2),'k:',...
    'LineWidth',1.5)
ylabel('St. Dev. of Sales Growth','FontSize',16);
axis([1990 2008 0 .05]);
legend('Analytical 95% C.I.','Boostrap 95% C.I.','Location','Best');
set(gca,'FontSize',12);
grid 'on'
print -depsc2 Figures/std_se_sales_ABS_MFG;

figure(2)
plot(t,sd_idio-1.96*sd_idio_se,'k--',t,prctile(sd_idio_BS,2.5,2),'k:', ...
    t,sd_idio,'ko-',t,sd_idio+1.96*sd_idio_se,'k--',t,prctile(sd_idio_BS,97.5,2),'k:',...
    'LineWidth',1.5)
ylabel('St. Dev. of Idiosyncratic Shock','FontSize',16);
axis([1990 2008 0 .05]);
legend('Analytical 95% C.I.','Boostrap 95% C.I.','Location','Best');
set(gca,'FontSize',12);
grid 'on'
print -depsc2 Figures/std_se_idio_ABS_MFG;

figure(3)
plot(t,sd_macsec-1.96*sd_macsec_se,'k--',t,sd_macsec,'ko-',t,sd_macsec+1.96*sd_macsec_se,'k--','LineWidth',1.5)
plot(t,sd_macsec-1.96*sd_macsec_se,'k--',t,prctile(sd_macsec_BS,2.5,2),'k:', ...
    t,sd_macsec,'ko-',t,sd_macsec+1.96*sd_macsec_se,'k--',t,prctile(sd_macsec_BS,97.5,2),'k:',...
    'LineWidth',1.5)
ylabel('St. Dev. of Macro-Sector Shock','FontSize',16);
axis([1990 2008 0 .05]);
legend('Analytical 95% C.I.','Boostrap 95% C.I.','Location','Best');
set(gca,'FontSize',12);
grid 'on'
print -depsc2 Figures/std_se_macsec_ABS_MFG;

