clear
close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Date: August 19, 2013
%
% Program: this file calculates necessary granulas residual, to bootstrap 
% from, and create standard error bans. Sample: Whole economy
%
% References to the following functions: 
%   gran_res.m
%   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


load Output/reg_output_all_ca;
gr_sales = gr_variable;
gr_macsec = gr_macro+gr_sec;

% Calculate residuals to boostrap from

gres_sales = gran_res(id_fp,year,gr_sales,w_fp);
gres_idio = gran_res(id_fp,year,gr_idio,w_fp);
gres_macsec = gran_res(id_fp,year,gr_macsec,w_fp);

% Bootstrapping loop: first draw years and then apply to three matrices

% Generate matrix of sampled time, with replacement

for i = 1:10001
     rand('twister', i)
     T(:,i) = randsample(1:17,17,true)';
end

% Sample over 10001 random draws to get distributions of st.deviations.
% Will create matrices of the inner products W'Y (gran res), where we draw
% a column of the gran residuals, which represents a similar vector of
% demeaned residuals (Y) pre-multiplied by the weights for 1 to T, where
% each row is a particular w_t. The column we choose from the bootstrap
% (T(t,i)), therefore represents the timing of the shocks (demeanded)

sd_sales_BS = [];
sd_idio_BS = [];
sd_macsec_BS = [];

for i = 1:10001
    Y1 = [];
    Y2 = [];
    Y3 = [];
    for t = 1:17
        y1 = gres_sales(:,T(t,i));
        y2 = gres_idio(:,T(t,i));
        y3 = gres_macsec(:,T(t,i));
        
        Y1 = [Y1 y1];
        Y2 = [Y2 y2];
        Y3 = [Y3 y3];
        
        clear y1 y2 y3
    end
    sd_sales = sqrt(diag(Y1*Y1'));
    sd_idio = sqrt(diag(Y2*Y2'));
    sd_macsec = sqrt(diag(Y3*Y3'));

    sd_sales_BS = [sd_sales_BS sd_sales];
    sd_idio_BS = [sd_idio_BS sd_idio];
    sd_macsec_BS = [sd_macsec_BS sd_macsec];
    
    clear Y1 Y2 Y3 sd_sales sd_idio sd_macsec;
end

sd_sales = sqrt(diag(gres_sales*gres_sales'));
sd_idio = sqrt(diag(gres_idio*gres_idio'));
sd_macsec = sqrt(diag(gres_macsec*gres_macsec'));

 % Save data to output file

save  Output/st_errors_BS_ALL sd_sales* sd_idio* sd_macsec*;
