clear;
close all;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Date: March 22, 2012
%
% Program: this file calculates the aggregate variance decomposition, by sector
% for the manufacturing sector
% 	1) creates aggregate variance and components using constant weights, by
% 	sector
%   2) creates aggregate variance and components using constant weights, by
% 	sector and normalize by the size of each sector
%   3) stores the matrix of weights, by sector
%   4) computes Herfindahl indices based on the distribution of weights, by
%   sector
% 
% References to the following functions: 
%   var_growth_cs.m (variance of aggregate growth, based on constant 
%   weights, by sector)
%   herfindahl_cs.m (Herfindahl index, by sector)
%   w_matrix.m sector-specific weights
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Get raw data

load('Output/reg_output_mfg_ca');

gr_macrosec = gr_macro+gr_sec;

% Create aggregate variance components: time-varying weights

[VAR_variable_cs COV_variable_cs COV_B_variable_cs VAR_TOTAL_variable_cs SD_TOTAL_variable_cs VAR_ONLY_variable_cs SD_ONLY_variable_cs COV_W_variable_cs] = var_growth_cs(id_fp,id_i,year,gr_variable,w_fp);
[VAR_idio_cs COV_idio_cs COV_B_idio_cs VAR_TOTAL_idio_cs SD_TOTAL_idio_cs VAR_ONLY_idio_cs SD_ONLY_idio_cs COV_W_idio_cs] = var_growth_cs(id_fp,id_i,year,gr_idio,w_fp);
[VAR_macrosec_cs COV_macrosec_cs COV_B_macrosec_cs VAR_TOTAL_macrosec_cs SD_TOTAL_macrosec_cs VAR_ONLY_macrosec_cs SD_ONLY_macrosec_cs COV_W_macrosec_cs] = var_growth_cs(id_ip,id_i,year,gr_macrosec,w_ip);
[VAR_variable_cs_i COV_variable_cs_i COV_B_variable_cs_i VAR_TOTAL_variable_cs_i SD_TOTAL_variable_cs_i VAR_ONLY_variable_cs_i SD_ONLY_variable_cs_i COV_W_variable_cs_i] = var_growth_cs(id_fp,id_i,year,gr_variable,w_fp./w_i);
[VAR_idio_cs_i COV_idio_cs_i COV_B_idio_cs_i VAR_TOTAL_idio_cs_i SD_TOTAL_idio_cs_i VAR_ONLY_idio_cs_i SD_ONLY_idio_cs_i COV_W_idio_cs_i] = var_growth_cs(id_fp,id_i,year,gr_idio,w_fp./w_i);
[VAR_macrosec_cs_i COV_macrosec_cs_i COV_B_macrosec_cs_i VAR_TOTAL_macrosec_cs_i SD_TOTAL_macrosec_cs_i VAR_ONLY_macrosec_cs_i SD_ONLY_macrosec_cs_i COV_W_macrosec_cs_i] = var_growth_cs(id_ip,id_i,year,gr_macrosec,w_ip./w_i);

% Keep matrix of weights, by sector

W_cs=w_matrix(id_fp,id_i,year,w_i);

% Compute herfindahl, by sector

[herf_cs] = herfindahl_cs(id_fp,id_i,year,w_fp);
[herf_cs_i] = herfindahl_cs(id_fp,id_i,year,w_fp./w_i);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Save output to smaller file
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear data gr_* w* year mw* id*;
save Output/master_variance_cs_mfg_ca;