/*******************************************************************************
	Date: December 2, 2011
	
	Program: prepares a .csv file of growth regression results to run in 
				Matlab for aggregate volatility calculations
				
				`1': file name output as a csv file
				`2': identifies whether an interacted regression or not (more vars): 0 if no additional controls, 1 if a single control
				`3': growth rate used as LHS in microestimation
********************************************************************************/


capture program drop matlab_prep
program define matlab_prep

	* Get rid of 2 only obs to avoid pain in Matlab later (dividing by 0 for T-1 in volatility calculations)
	egen id_i=group($sect)
	egen id_ip=group($sect pays)

	egen cobs = count(`3'), by(id_ip id_fp)
	drop if cobs<2
	drop cobs
	
	bysort year: egen w_tot=sum(w_fn)
	g w_fp=w_fn/w_tot
	drop w_tot
	
	drop id_i id_ip id_f id_fp
	sort $sect pays siren year
	
	egen id_fp=group(siren pays)
	egen id_f=group(siren)
	egen id_i=group($sect)
	egen id_ip=group($sect pays)
	egen id_ipy=group($sect pays year)

	egen w_f = sum(w_fp), by(id_f year)
	egen w_ip = sum(w_fp), by(id_ip year)
	egen w_i = sum(w_fp), by(id_i year)
	egen w_p = sum(w_fp), by(id_p year)


	if `2' == 0{
		order id_fp id_f id_ip id_i id_p year id_ipy `3' gr_idio gr_idio_com gr_idio_dest gr_sec gr_macro w_fp w_f w_ip w_i w_p  
		keep  id_fp id_f id_ip id_i id_p year id_ipy `3' gr_idio gr_idio_com gr_idio_dest gr_sec gr_macro w_fp w_f w_ip w_i w_p  
	}
	
	else if `2' == 1{	
		order id_fp id_f id_ip id_i id_p year id_ipy `3' gr_idio gr_idio_com gr_idio_dest gr_sec gr_size gr_sizesec gr_macro w_fp w_f w_ip w_i w_p 
		keep id_fp id_f id_ip id_i id_p year id_ipy `3' gr_idio gr_idio_com gr_idio_dest gr_sec gr_size gr_sizesec gr_macro w_fp w_f w_ip w_i w_p  
	}

	
	sort id_fp year

	outsheet using `1'.csv, comma replace
end
