/*
   Date: May 29, 2011
	
   Program: this program decomposes market-specific individual growth rates into a firm, a sector and an aggregate components. 
                                    the firm-specific component into a common and a market-specific shocks
						controls for multiple firm-specific characteristics
   
   
            `1': input file
			`2': Sector variable
			`3': Reference sector
			`4': Growth variable
			`5': Output file
			`6' : nb of control variables
			`7' to `N': Control variabls
*/

capture program drop multi_interacted_growth_regs
program define multi_interacted_growth_regs

global countvar = `6'

*** First stage: Idio/sector/macro
set more off
cd $datapath
use `1', clear
sum id_p
local min_id_p = r(min)
local max_id_p = r(max)

foreach P of numlist `min_id_p'/`max_id_p'{
	di "num pays"
	di `P'
	keep if id_p==`P'
	sum year if id_p==`P'

	local min_year = r(min)
	local max_year = r(max)

	save _temp_`P',replace
	foreach Y of numlist `min_year'/`max_year'{
		di "num year"
		di `Y'
		keep if year == `Y'
		sort `2'
		by `2': egen count=count(`4') if `4'!=. & $conditionvar
		drop if count==1
		egen naf_num = group(`2')
		quietly sum naf_num if `2'==`3'
		local sc = r(min)
		quietly tab naf_num, ge(sec)
		sum naf_num
		local nafmin = r(min)
		local nafmax = r(max)
		di "count sectors"
		di `nafmax'
		local g = `nafmax'
		global varlist 
		foreach C in `7' `8' `9' `10' `11' `12' `13' `14' `15'{
			foreach N of numlist `nafmin'/`nafmax'{	
				ge intsec`C'`N'=`C'*sec`N'
				quietly corr intsec`C'`N' sec`N'
				local rho = r(rho)
				sum naf_num if `N'==naf_num
				local obs = r(N)
				if `rho'>=.9999 | `obs'<=4{
					drop intsec`C'`N'	
					local g = `g'-1
				}
				else{
				global varlist $varlist intsec`C'`N'
				}
			}
		}
		quietly tab pct if naf_num==`sc'
		local psc=r(r)
		
		quietly count
		local count = r(N)

		if `count'>25 & `g'>1 & `psc'>1{
			constraint 1 sec`sc' = 0
			local ii = 2
			foreach C in `7' `8' `9' `10' `11' `12' `13' `14' `15'{
				constraint `ii' intsec`C'`sc' = 0
				local ii=`ii'+1
			}
			local count_cns=$countvar+1
			
			* Regression

			cnsreg `4' `7' `8' `9' `10' `11' `12' `13' `14' `15' sec* $varlist , c(1-`count_cns')

			* Idiosyncratic shock

			predict gr_idio, res
   
			* R-squared
   
			predict `4'_hat
			corr `4' `4'_hat if e(sample) 
			ge Rsquared=r(rho)^2

			* Estimated coefficients on firm-level variables
			
			mat b = e(b)
			local ii = 1
			foreach C in `7' `8' `9' `10' `11' `12' `13' `14' `15'{
				if $countvar>=`ii'{
					local jj=`ii'+1
					mat b_int`C'=b[1,`ii']
				}
			local ii = `ii'+1
			}
	
			* Adjust R squared
			quietly sum `4' if e(sample)
			local count=r(N)
			g countreg=colsof(b)
			quietly sum countreg
			local countreg=r(mean)
			ge Rbarsquared=1-(1-Rsquared)*(`count'-1)/(`count'-`countreg'-1)
	
	
			* size effect
			global varlist
			foreach C in `7' `8' `9' `10' `11' `12' `13' `14' `15'{
				ge gr_int`C'= b_int`C'[1,1] * `C'
				corr `4' gr_int`C' if e(sample)
				ge Rspart_int`C'=r(rho)^2
				global varlist $varlist-gr_int`C'
			}
			
		
			* Destination-sec effects (including contribution of sector FE interacted with firm-level controls)
			ge gr_macrosec=`4'-gr_idio $varlist
			corr `4' gr_macrosec if e(sample) 
			ge Rspart_macrosec=r(rho)^2
		}
		
		else{
			ge gr_idio=0
			ge `4'_hat=0
			ge Rsquared=0
			ge Rbarsquared=0
			foreach C in `7' `8' `9' `10' `11' `12' `13' `14' `15'{
				ge gr_intsec`C' = 0
				ge Rspart_intsec`C'=0
			}
			ge gr_macrosec=0
			ge Rspart_macrosec=0
		}
		keep siren id* `2' year `4' `7' `8' `9' `10' `11' `12' `13' `14' `15' pays gr_idio gr_int* gr_macrosec Rsquared Rbarsquared Rspart_macrosec Rspart_int* `4'_hat w_fn
		compress
		save _temp`P'`Y', replace
		use _temp_`P', clear
	}
	
	use _temp`P'`min_year', clear
	local min_year1 = `min_year'+1
	foreach X of numlist `min_year1'/`max_year'{
		append using _temp`P'`X'
		erase _temp`P'`X'.dta
	}
	sort pays year
	save _growth_`P'_regs, replace
	erase _temp`P'`min_year'.dta
    erase _temp_`P'.dta
	use `1', clear
}

local min_id_p1 = `min_id_p'+1
use _growth_`min_id_p'_regs, clear
foreach P of numlist `min_id_p1'/`max_id_p'{
	append using _growth_`P'_regs
	erase _growth_`P'_regs.dta
}

save `5', replace
erase _growth_`min_id_p'_regs.dta

*** Second stage: Firm-common/Firm-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated firm-level residuals
	that were estimated in the first-step
	regressions above.
	
	Note: regress for firms that have at 
	2mkts so we can identify correctly
*******************************************/

use `5', clear

capture egen id_p = group(pays)
egen q = count(id_p), by(siren year)

egen gr_idio_com = mean(gr_idio) if q>1, by(siren year)
ge gr_idio_dest = gr_idio - gr_idio_com if q>1
keep siren pays year gr_idio_com gr_idio_dest w_fn
sort siren pays year

save temp_idio, replace

use `5', clear

sort siren pays year
merge siren pays year using temp_idio
tab _m
drop _m

sort siren pays year
save `5', replace

erase temp_idio.dta

end
