/*
   Date: December, 2012
	
   Program: this program decomposes market-specific individual growth rates into a firm, a sector, a local and an aggregate components. 
                                    the firm-specific component into a common and a market-specific shocks
			Specification has sector*destination effects + local market effects
   
   
             `1': input file
			`2': growth rate variable
			`3': Output file 
*/

capture program drop threesteps_growth_regs_localef
program define threesteps_growth_regs_localef

*** First stage: Idio/sector/macro/local
set more off
use `1', clear
sum id_p
local min_id_p = r(min)
local max_id_p = r(max)
foreach P of numlist `min_id_p'/`max_id_p'{
	keep if id_p==`P'
	sum year if id_p==`P'
	local min_year = r(min)
	local max_year = r(max)
	save temp_`P',replace
	foreach X of numlist `min_year'/`max_year'{
		growth_reg_localef `2' $sect `X' $refsect
		save temp`P'`X', replace
		use temp_`P', clear
	}
	use temp`P'`min_year', clear
	local min_year1 = `min_year'+1
	foreach X of numlist `min_year1'/`max_year'{
		append using temp`P'`X'
		erase temp`P'`X'.dta
	}
	sort pays year
	save $outputpath/growth_`P'_regs_$sample$dataset, replace
	erase temp`P'`min_year'.dta
    erase temp_`P'.dta
	use `1', clear
}

local min_id_p1 = `min_id_p'+1
use $outputpath/growth_`min_id_p'_regs_$sample$dataset, clear
foreach P of numlist `min_id_p1'/`max_id_p'{
	append using $outputpath/growth_`P'_regs_$sample$dataset
	erase $outputpath/growth_`P'_regs_$sample$dataset.dta
}

save `3', replace
erase $outputpath/growth_`min_id_p'_regs_$sample$dataset.dta

*** Second stage: Sector-common/sector-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated sector-level coefficients
	that were estimated in the first-step
	regressions above.
*******************************************/

use `3', clear
bysort $sect pays year: keep if _n==1

egen gr_sec_com = mean(gr_sec), by($sect year)
ge gr_sec_dest = gr_sec - gr_sec_com
keep pays $sect year gr_sec_com gr_sec_dest w_fn
sort $sect pays year

save temp_sec, replace

*** Third stage: Local-common/Local-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated local-level coefficients
	that were estimated in the first-step
	regressions above.
*******************************************/

use `3', clear
bysort id_z pays year: keep if _n==1

egen gr_ze_com = mean(gr_ze), by(id_z year)
ge gr_ze_dest = gr_ze - gr_ze_com
keep pays id_z year gr_ze_com gr_ze_dest w_fn
sort id_z pays year

save temp_ze, replace

*** Fourth stage: Firm-common/Firm-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated firm-level residuals
	that were estimated in the first-step
	regressions above.
	
	AUG 3: regress for firms that have at 
	2mkts so we can identify correctly
*******************************************/

use `3', clear

capture egen id_p = group(pays)
egen q = count(id_p), by(siren year)

egen gr_idio_com = mean(gr_idio) if q>1, by(siren year)
ge gr_idio_dest = gr_idio - gr_idio_com if q>1
keep siren pays year gr_idio_com gr_idio_dest w_fn
sort siren pays year

save temp_idio, replace

use `3', clear
sort $sect pays year
merge $sect pays year using temp_sec
tab _m
drop _m

sort id_z pays year
merge id_z pays year using temp_ze
tab _m
drop _m

sort siren pays year
merge siren pays year using temp_idio
tab _m
drop _m

sort siren pays year
save `3', replace

erase temp_sec.dta
erase temp_idio.dta
erase temp_ze.dta

end
