/*
   Date: May 29, 2011
	
   Program: this program decomposes market-specific individual growth rates into a firm, a sector and an aggregate components. 
                                    the firm-specific component into a common and a market-specific shocks
   
   
            `1': input file
			`2': growth rate variable
			`3': Output file 
*/

capture program drop threesteps_growth_regs_naf700
program define threesteps_growth_regs_naf700

*** First stage: Idio/sector/macro
set more off
use `1', clear
sum id_p
local min_id_p = r(min)
local max_id_p = r(max)
foreach P of numlist `min_id_p'/`max_id_p'{
	keep if id_p==`P'
	sum year if id_p==`P' & `2'!=.
	local min_year = r(min)
	local max_year = r(max)
	save temp_`P',replace
	foreach X of numlist `min_year'/`max_year'{
		growth_regs_naf700 `2' $sect `X' $refsect
		save temp`P'`X', replace
		use temp_`P', clear
	}
	use temp`P'`min_year', clear
	local min_year1 = `min_year'+1
	foreach X of numlist `min_year1'/`max_year'{
		append using temp`P'`X'
		erase temp`P'`X'.dta
	}
	sort pays year
	save growth_`P'_regs, replace
	erase temp`P'`min_year'.dta
    erase temp_`P'.dta
	use `1', clear
}

local min_id_p1 = `min_id_p'+1
use growth_`min_id_p'_regs, clear
foreach P of numlist `min_id_p1'/`max_id_p'{
	append using growth_`P'_regs
	erase growth_`P'_regs.dta
}

save `3', replace
erase growth_`min_id_p'_regs.dta

*** Second stage: Firm-common/Firm-market-specific

/*******************************************
	This "regression" will extract the common
	and destination specific components of
	the estimated firm-level residuals
	that were estimated in the first-step
	regressions above.
	
	Note: regress for firms that have at 
	2mkts so we can identify correctly
*******************************************/

use `3', clear

capture egen id_p = group(pays)
egen q = count(id_p), by(siren year)

egen gr_idio_com = mean(gr_idio) if q>1, by(siren year)
ge gr_idio_dest = gr_idio - gr_idio_com if q>1
keep siren pays year gr_idio_com gr_idio_dest w_fn
sort siren pays year

save temp_idio, replace

use `3', clear
sort siren pays year
merge siren pays year using temp_idio
tab _m
drop _m

sort siren pays year
save `3', replace

erase temp_idio.dta

end
